@@ -21,92 +21,77 @@
 
 #include "newmailnotifieragent.h"
 
-#include "newmailnotifierattribute.h"
+#include <AkonadiCore/NewMailNotifierAttribute>
 #include "specialnotifierjob.h"
 #include "newmailnotifieradaptor.h"
 #include "newmailnotifieragentsettings.h"
 #include "newmailnotifiersettingsdialog.h"
 
-#include <KPIMIdentities/IdentityManager>
+#include <KIdentityManagement/IdentityManager>
 
-#include <akonadi/dbusconnectionpool.h>
+#include <kdbusconnectionpool.h>
 
-#include <akonadi/agentfactory.h>
-#include <akonadi/changerecorder.h>
-#include <akonadi/entitydisplayattribute.h>
-#include <akonadi/entityhiddenattribute.h>
-#include <akonadi/itemfetchscope.h>
-#include <akonadi/session.h>
-#include <Akonadi/AttributeFactory>
-#include <Akonadi/CollectionFetchScope>
-#include <akonadi/kmime/specialmailcollections.h>
-#include <akonadi/kmime/messagestatus.h>
-#include <Akonadi/AgentManager>
+#include <agentfactory.h>
+#include <changerecorder.h>
+#include <entitydisplayattribute.h>
+#include <entityhiddenattribute.h>
+#include <itemfetchscope.h>
+#include <session.h>
+#include <AttributeFactory>
+#include <CollectionFetchScope>
+#include <Akonadi/KMime/SpecialMailCollections>
+#include <Akonadi/KMime/MessageStatus>
+#include <AgentManager>
 #include <KLocalizedString>
 #include <KMime/Message>
 #include <KNotification>
-#include <KNotifyConfigWidget>
-#include <KIconLoader>
-#include <KIcon>
-#include <KConfigGroup>
-#include <KLocalizedString>
 #include <KWindowSystem>
+#include <Kdelibs4ConfigMigrator>
+#include "newmailnotifier_debug.h"
 #include <KToolInvocation>
-
+#include <QIcon>
+#include <KIconLoader>
 
 using namespace Akonadi;
 
-NewMailNotifierAgent::NewMailNotifierAgent( const QString &id )
-    : AgentBase( id )
+NewMailNotifierAgent::NewMailNotifierAgent(const QString &id)
+    : AgentBase(id)
 {
-    Akonadi::AttributeFactory::registerAttribute<NewMailNotifierAttribute>();
-    new NewMailNotifierAdaptor( this );
+    Kdelibs4ConfigMigrator migrate(QStringLiteral("newmailnotifieragent"));
+    migrate.setConfigFiles(QStringList() << QStringLiteral("akonadi_newmailnotifier_agentrc") << QStringLiteral("akonadi_newmailnotifier_agent.notifyrc"));
+    migrate.migrate();
 
-    mIdentityManager = new KPIMIdentities::IdentityManager( false, this );
+    KLocalizedString::setApplicationDomain("akonadi_newmailnotifier_agent");
+    Akonadi::AttributeFactory::registerAttribute<Akonadi::NewMailNotifierAttribute>();
+    new NewMailNotifierAdaptor(this);
+
+    mIdentityManager = new KIdentityManagement::IdentityManager(false, this);
     connect(mIdentityManager, SIGNAL(changed()), SLOT(slotIdentitiesChanged()));
     slotIdentitiesChanged();
-    mDefaultPixmap = KIcon( QLatin1String("kmail") ).pixmap( KIconLoader::SizeMedium, KIconLoader::SizeMedium );
+    mDefaultPixmap = QIcon::fromTheme(QStringLiteral("kmail")).pixmap(KIconLoader::SizeMedium, KIconLoader::SizeMedium);
 
-    DBusConnectionPool::threadConnection().registerObject( QLatin1String( "/NewMailNotifierAgent" ),
-                                                           this, QDBusConnection::ExportAdaptors );
-    DBusConnectionPool::threadConnection().registerService( QLatin1String( "org.freedesktop.Akonadi.NewMailNotifierAgent" ) );
+    KDBusConnectionPool::threadConnection().registerObject(QStringLiteral("/NewMailNotifierAgent"),
+            this, QDBusConnection::ExportAdaptors);
+    KDBusConnectionPool::threadConnection().registerService(QStringLiteral("org.freedesktop.Akonadi.NewMailNotifierAgent"));
 
-    connect( Akonadi::AgentManager::self(), SIGNAL(instanceStatusChanged(Akonadi::AgentInstance)),
-             this, SLOT(slotInstanceStatusChanged(Akonadi::AgentInstance)) );
-    connect( Akonadi::AgentManager::self(), SIGNAL(instanceRemoved(Akonadi::AgentInstance)),
-             this, SLOT(slotInstanceRemoved(Akonadi::AgentInstance)) );
-    connect( Akonadi::AgentManager::self(), SIGNAL(instanceAdded(Akonadi::AgentInstance)),
-             this, SLOT(slotInstanceAdded(Akonadi::AgentInstance)) );
-    connect( Akonadi::AgentManager::self(), SIGNAL(instanceNameChanged(Akonadi::AgentInstance)),
-             this, SLOT(slotInstanceNameChanged(Akonadi::AgentInstance)) );
+    connect(Akonadi::AgentManager::self(), &Akonadi::AgentManager::instanceStatusChanged, this, &NewMailNotifierAgent::slotInstanceStatusChanged);
+    connect(Akonadi::AgentManager::self(), &Akonadi::AgentManager::instanceRemoved, this, &NewMailNotifierAgent::slotInstanceRemoved);
+    connect(Akonadi::AgentManager::self(), &Akonadi::AgentManager::instanceAdded, this, &NewMailNotifierAgent::slotInstanceAdded);
+    connect(Akonadi::AgentManager::self(), &Akonadi::AgentManager::instanceNameChanged, this, &NewMailNotifierAgent::slotInstanceNameChanged);
 
-
-    changeRecorder()->setMimeTypeMonitored( KMime::Message::mimeType() );
-    changeRecorder()->itemFetchScope().setCacheOnly( true );
-    changeRecorder()->itemFetchScope().setFetchModificationTime( false );
-    changeRecorder()->fetchCollection( true );
-    changeRecorder()->setChangeRecordingEnabled( false );
-    changeRecorder()->ignoreSession( Akonadi::Session::defaultSession() );
-    changeRecorder()->collectionFetchScope().setAncestorRetrieval( Akonadi::CollectionFetchScope::All );
+    changeRecorder()->setMimeTypeMonitored(KMime::Message::mimeType());
+    changeRecorder()->itemFetchScope().setCacheOnly(true);
+    changeRecorder()->itemFetchScope().setFetchModificationTime(false);
+    changeRecorder()->fetchCollection(true);
+    changeRecorder()->setChangeRecordingEnabled(false);
+    changeRecorder()->ignoreSession(Akonadi::Session::defaultSession());
+    changeRecorder()->collectionFetchScope().setAncestorRetrieval(Akonadi::CollectionFetchScope::All);
     changeRecorder()->setCollectionMonitored(Collection::root(), true);
-    mTimer.setInterval( 5 * 1000 );
-    connect( &mTimer, SIGNAL(timeout()), SLOT(slotShowNotifications()) );
+    mTimer.setInterval(5 * 1000);
+    connect(&mTimer, &QTimer::timeout, this, &NewMailNotifierAgent::slotShowNotifications);
 
-    if (NewMailNotifierAgentSettings::textToSpeakEnabled()) {
-        if (!QDBusConnection::sessionBus().interface()->isServiceRegistered(QLatin1String("org.kde.kttsd"))) {
-            QString error;
-            if (KToolInvocation::startServiceByDesktopName(QLatin1String("kttsd"), QStringList(), &error)) {
-                KNotification::event( QLatin1String("text-to-speak-not-found"),
-                                      i18n("Starting Jovie Text-to-Speech Service Failed %1", error),
-                                      mDefaultPixmap,
-                                      0,
-                                      KNotification::CloseOnTimeout,
-                                      KGlobal::mainComponent());
-            }
-        }
-    }
     if (isActive()) {
-        mTimer.setSingleShot( true );
+        mTimer.setSingleShot(true);
     }
 }
 
@@ -125,7 +110,7 @@ void NewMailNotifierAgent::doSetOnline(bool online)
 void NewMailNotifierAgent::setExcludeMyselfFromNotification(bool b)
 {
     NewMailNotifierAgentSettings::setExcludeEmailsFromMe(b);
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
 }
 
 bool NewMailNotifierAgent::excludeMyselfFromNotification() const
@@ -136,7 +121,7 @@ bool NewMailNotifierAgent::excludeMyselfFromNotification() const
 void NewMailNotifierAgent::setShowPhoto(bool show)
 {
     NewMailNotifierAgentSettings::setShowPhoto(show);
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
 }
 
 bool NewMailNotifierAgent::showPhoto() const
@@ -147,7 +132,7 @@ bool NewMailNotifierAgent::showPhoto() const
 void NewMailNotifierAgent::setShowFrom(bool show)
 {
     NewMailNotifierAgentSettings::setShowFrom(show);
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
 }
 
 bool NewMailNotifierAgent::showFrom() const
@@ -158,7 +143,7 @@ bool NewMailNotifierAgent::showFrom() const
 void NewMailNotifierAgent::setShowSubject(bool show)
 {
     NewMailNotifierAgentSettings::setShowSubject(show);
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
 }
 
 bool NewMailNotifierAgent::showSubject() const
@@ -169,7 +154,7 @@ bool NewMailNotifierAgent::showSubject() const
 void NewMailNotifierAgent::setShowFolderName(bool show)
 {
     NewMailNotifierAgentSettings::setShowFolder(show);
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
 }
 
 bool NewMailNotifierAgent::showFolderName() const
@@ -180,7 +165,7 @@ bool NewMailNotifierAgent::showFolderName() const
 void NewMailNotifierAgent::setEnableAgent(bool enabled)
 {
     NewMailNotifierAgentSettings::setEnabled(enabled);
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
     if (!enabled) {
         clearAll();
     }
@@ -189,7 +174,7 @@ void NewMailNotifierAgent::setEnableAgent(bool enabled)
 void NewMailNotifierAgent::setVerboseMailNotification(bool verbose)
 {
     NewMailNotifierAgentSettings::setVerboseNotification(verbose);
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
 }
 
 bool NewMailNotifierAgent::verboseMailNotification() const
@@ -200,7 +185,7 @@ bool NewMailNotifierAgent::verboseMailNotification() const
 void NewMailNotifierAgent::setBeepOnNewMails(bool beep)
 {
     NewMailNotifierAgentSettings::setBeepOnNewMails(beep);
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
 }
 
 bool NewMailNotifierAgent::beepOnNewMails() const
@@ -211,7 +196,7 @@ bool NewMailNotifierAgent::beepOnNewMails() const
 void NewMailNotifierAgent::setTextToSpeakEnabled(bool enabled)
 {
     NewMailNotifierAgentSettings::setTextToSpeakEnabled(enabled);
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
 }
 
 bool NewMailNotifierAgent::textToSpeakEnabled() const
@@ -222,7 +207,7 @@ bool NewMailNotifierAgent::textToSpeakEnabled() const
 void NewMailNotifierAgent::setTextToSpeak(const QString &msg)
 {
     NewMailNotifierAgentSettings::setTextToSpeak(msg);
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
 }
 
 QString NewMailNotifierAgent::textToSpeak() const
@@ -249,23 +234,22 @@ bool NewMailNotifierAgent::showButtonToDisplayMail() const
 void NewMailNotifierAgent::setShowButtonToDisplayMail(bool b)
 {
     NewMailNotifierAgentSettings::setShowButtonToDisplayMail(b);
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
 }
 
-
 void NewMailNotifierAgent::showConfigureDialog(qlonglong windowId)
 {
-    configure( windowId );
+    configure(windowId);
 }
 
-void NewMailNotifierAgent::configure( WId windowId )
+void NewMailNotifierAgent::configure(WId windowId)
 {
     QPointer<NewMailNotifierSettingsDialog> dialog = new NewMailNotifierSettingsDialog;
     if (windowId) {
-#ifndef Q_WS_WIN
-        KWindowSystem::setMainWindow( dialog, windowId );
+#ifndef Q_OS_WIN
+        KWindowSystem::setMainWindow(dialog, windowId);
 #else
-        KWindowSystem::setMainWindow( dialog, (HWND)windowId );
+        KWindowSystem::setMainWindow(dialog, (HWND)windowId);
 #endif
     }
     dialog->exec();
@@ -274,21 +258,22 @@ void NewMailNotifierAgent::configure( WId windowId )
 
 bool NewMailNotifierAgent::excludeSpecialCollection(const Akonadi::Collection &collection) const
 {
-    if ( collection.hasAttribute<Akonadi::EntityHiddenAttribute>() )
+    if (collection.hasAttribute<Akonadi::EntityHiddenAttribute>()) {
         return true;
+    }
 
-    if ( collection.hasAttribute<NewMailNotifierAttribute>() ) {
-        if (collection.attribute<NewMailNotifierAttribute>()->ignoreNewMail()) {
+    if (collection.hasAttribute<Akonadi::NewMailNotifierAttribute>()) {
+        if (collection.attribute<Akonadi::NewMailNotifierAttribute>()->ignoreNewMail()) {
             return true;
         }
     }
 
-    if (!collection.contentMimeTypes().contains( KMime::Message::mimeType()) ) {
+    if (!collection.contentMimeTypes().contains(KMime::Message::mimeType())) {
         return true;
     }
 
     SpecialMailCollections::Type type = SpecialMailCollections::self()->specialCollectionType(collection);
-    switch(type) {
+    switch (type) {
     case SpecialMailCollections::Invalid: //Not a special collection
     case SpecialMailCollections::Inbox:
         return false;
@@ -298,24 +283,25 @@ bool NewMailNotifierAgent::excludeSpecialCollection(const Akonadi::Collection &c
 
 }
 
-void NewMailNotifierAgent::itemsRemoved(const Item::List &items )
+void NewMailNotifierAgent::itemsRemoved(const Item::List &items)
 {
-    if (!isActive())
+    if (!isActive()) {
         return;
+    }
 
     QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::iterator end(mNewMails.end());
-    for ( QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::iterator it = mNewMails.begin(); it != end; ++it ) {
+    for (QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::iterator it = mNewMails.begin(); it != end; ++it) {
         QList<Akonadi::Item::Id> idList = it.value();
         bool itemFound = false;
-        Q_FOREACH( const Item &item, items ) {
+        Q_FOREACH (const Item &item, items) {
             if (idList.contains(item.id())) {
-                idList.removeAll( item.id() );
+                idList.removeAll(item.id());
                 itemFound = true;
             }
         }
         if (itemFound) {
             if (mNewMails[it.key()].isEmpty()) {
-                mNewMails.remove( it.key() );
+                mNewMails.remove(it.key());
             } else {
                 mNewMails[it.key()] = idList;
             }
@@ -323,18 +309,19 @@ void NewMailNotifierAgent::itemsRemoved(const Item::List &items )
     }
 }
 
-void NewMailNotifierAgent::itemsFlagsChanged( const Akonadi::Item::List &items, const QSet<QByteArray> &addedFlags, const QSet<QByteArray> &removedFlags )
+void NewMailNotifierAgent::itemsFlagsChanged(const Akonadi::Item::List &items, const QSet<QByteArray> &addedFlags, const QSet<QByteArray> &removedFlags)
 {
-    if (!isActive())
+    if (!isActive()) {
         return;
+    }
     Q_FOREACH (const Akonadi::Item &item, items) {
         QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::iterator end(mNewMails.end());
-        for ( QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::iterator it = mNewMails.begin(); it != end; ++it ) {
-            QList<Akonadi::Item::Id> idList= it.value();
+        for (QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::iterator it = mNewMails.begin(); it != end; ++it) {
+            QList<Akonadi::Item::Id> idList = it.value();
             if (idList.contains(item.id()) && addedFlags.contains("\\SEEN")) {
-                idList.removeAll( item.id() );
-                if ( idList.isEmpty() ) {
-                    mNewMails.remove( it.key() );
+                idList.removeAll(item.id());
+                if (idList.isEmpty()) {
+                    mNewMails.remove(it.key());
                     break;
                 } else {
                     (*it) = idList;
@@ -344,33 +331,34 @@ void NewMailNotifierAgent::itemsFlagsChanged( const Akonadi::Item::List &items,
     }
 }
 
-void NewMailNotifierAgent::itemsMoved( const Akonadi::Item::List &items, const Akonadi::Collection &collectionSource, const Akonadi::Collection &collectionDestination )
+void NewMailNotifierAgent::itemsMoved(const Akonadi::Item::List &items, const Akonadi::Collection &collectionSource, const Akonadi::Collection &collectionDestination)
 {
-    if (!isActive())
+    if (!isActive()) {
         return;
+    }
 
     Q_FOREACH (const Akonadi::Item &item, items) {
         if (ignoreStatusMail(item)) {
             continue;
         }
 
-        if ( excludeSpecialCollection(collectionSource) ) {
+        if (excludeSpecialCollection(collectionSource)) {
             continue; // outbox, sent-mail, trash, drafts or templates.
         }
 
-        if ( mNewMails.contains( collectionSource ) ) {
+        if (mNewMails.contains(collectionSource)) {
             QList<Akonadi::Item::Id> idListFrom = mNewMails[ collectionSource ];
-            if ( idListFrom.contains( item.id() ) ) {
-                idListFrom.removeAll( item.id() );
+            if (idListFrom.contains(item.id())) {
+                idListFrom.removeAll(item.id());
 
-                if ( idListFrom.isEmpty() ) {
-                    mNewMails.remove( collectionSource );
+                if (idListFrom.isEmpty()) {
+                    mNewMails.remove(collectionSource);
                 } else {
                     mNewMails[ collectionSource ] = idListFrom;
                 }
-                if ( !excludeSpecialCollection(collectionDestination) ) {
+                if (!excludeSpecialCollection(collectionDestination)) {
                     QList<Akonadi::Item::Id> idListTo = mNewMails[ collectionDestination ];
-                    idListTo.append( item.id() );
+                    idListTo.append(item.id());
                     mNewMails[ collectionDestination ] = idListTo;
                 }
             }
@@ -381,18 +369,20 @@ void NewMailNotifierAgent::itemsMoved( const Akonadi::Item::List &items, const A
 bool NewMailNotifierAgent::ignoreStatusMail(const Akonadi::Item &item)
 {
     Akonadi::MessageStatus status;
-    status.setStatusFromFlags( item.flags() );
-    if ( status.isRead() || status.isSpam() || status.isIgnored() )
+    status.setStatusFromFlags(item.flags());
+    if (status.isRead() || status.isSpam() || status.isIgnored()) {
         return true;
+    }
     return false;
 }
 
-void NewMailNotifierAgent::itemAdded( const Akonadi::Item &item, const Akonadi::Collection &collection )
+void NewMailNotifierAgent::itemAdded(const Akonadi::Item &item, const Akonadi::Collection &collection)
 {
-    if (!isActive())
+    if (!isActive()) {
         return;
+    }
 
-    if ( excludeSpecialCollection(collection) ) {
+    if (excludeSpecialCollection(collection)) {
         return; // outbox, sent-mail, trash, drafts or templates.
     }
 
@@ -400,19 +390,21 @@ void NewMailNotifierAgent::itemAdded( const Akonadi::Item &item, const Akonadi::
         return;
     }
 
-    if ( !mTimer.isActive() ) {
+    if (!mTimer.isActive()) {
         mTimer.start();
     }
-    mNewMails[ collection ].append( item.id() );
+    mNewMails[ collection ].append(item.id());
 }
 
 void NewMailNotifierAgent::slotShowNotifications()
 {
-    if (mNewMails.isEmpty())
+    if (mNewMails.isEmpty()) {
         return;
+    }
 
-    if (!isActive())
+    if (!isActive()) {
         return;
+    }
 
     if (!mInstanceNameInProgress.isEmpty()) {
         //Restart timer until all is done.
@@ -428,23 +420,25 @@ void NewMailNotifierAgent::slotShowNotifications()
         QStringList texts;
         QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::const_iterator end(mNewMails.constEnd());
         const int numberOfCollection(mNewMails.count());
-        if (numberOfCollection > 1)
+        if (numberOfCollection > 1) {
             hasUniqMessage = false;
+        }
 
-        for ( QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::const_iterator it = mNewMails.constBegin(); it != end; ++it ) {
+        for (QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::const_iterator it = mNewMails.constBegin(); it != end; ++it) {
             Akonadi::EntityDisplayAttribute *attr = it.key().attribute<Akonadi::EntityDisplayAttribute>();
             QString displayName;
-            if ( attr && !attr->displayName().isEmpty() )
+            if (attr && !attr->displayName().isEmpty()) {
                 displayName = attr->displayName();
-            else
+            } else {
                 displayName = it.key().name();
+            }
 
             if (hasUniqMessage) {
                 if (it.value().count() == 0) {
                     //You can have an unique folder with 0 message
                     return;
-                } else if (it.value().count() == 1 ) {
-                    item = it.value().first();
+                } else if (it.value().count() == 1) {
+                    item = it.value().at(0);
                     currentPath = displayName;
                     break;
                 } else {
@@ -453,7 +447,7 @@ void NewMailNotifierAgent::slotShowNotifications()
             }
             QString resourceName;
             if (!mCacheResourceName.contains(it.key().resource())) {
-                Q_FOREACH ( const Akonadi::AgentInstance &instance, Akonadi::AgentManager::self()->instances() ) {
+                Q_FOREACH (const Akonadi::AgentInstance &instance, Akonadi::AgentManager::self()->instances()) {
                     if (instance.identifier() == it.key().resource()) {
                         mCacheResourceName.insert(instance.identifier(), instance.name());
                         resourceName = instance.name();
@@ -464,50 +458,53 @@ void NewMailNotifierAgent::slotShowNotifications()
                 resourceName = mCacheResourceName.value(it.key().resource());
             }
             const int numberOfEmails(it.value().count());
-            if (numberOfEmails>0) {
-                texts.append( i18np( "One new email in %2 from \"%3\"", "%1 new emails in %2 from \"%3\"", numberOfEmails, displayName,
-                                 resourceName ) );
+            if (numberOfEmails > 0) {
+                texts.append(i18ncp("%2 = name of mail folder; %3 = name of Akonadi POP3/IMAP/etc resource (as user named it)",
+                                    "One new email in %2 from \"%3\"",
+                                    "%1 new emails in %2 from \"%3\"", numberOfEmails, displayName,
+                                   resourceName));
             }
         }
         if (hasUniqMessage) {
             SpecialNotifierJob *job = new SpecialNotifierJob(mListEmails, currentPath, item, this);
             job->setDefaultPixmap(mDefaultPixmap);
-            connect(job, SIGNAL(displayNotification(QPixmap,QString)), SLOT(slotDisplayNotification(QPixmap,QString)));
+            connect(job, &SpecialNotifierJob::displayNotification, this, &NewMailNotifierAgent::slotDisplayNotification);
+
             mNewMails.clear();
             return;
         } else {
-            message = texts.join( QLatin1String("<br>") );
+            message = texts.join(QStringLiteral("<br>"));
         }
     } else {
-        message = i18n( "New mail arrived" );
+        message = i18n("New mail arrived");
     }
 
-    kDebug() << message;
+    qCDebug(NEWMAILNOTIFIER_LOG) << message;
 
     slotDisplayNotification(mDefaultPixmap, message);
 
     mNewMails.clear();
 }
 
-
 void NewMailNotifierAgent::slotDisplayNotification(const QPixmap &pixmap, const QString &message)
 {
-    KNotification::event( QLatin1String("new-email"),
-                          message,
-                          pixmap,
-                          0,
-                          KNotification::CloseOnTimeout,
-                          KGlobal::mainComponent());
+    KNotification::event(QStringLiteral("new-email"),
+                         message,
+                         pixmap,
+                         Q_NULLPTR,
+                         KNotification::CloseOnTimeout,
+                         QStringLiteral("akonadi_newmailnotifier_agent"));
 
-    if ( NewMailNotifierAgentSettings::beepOnNewMails() ) {
+    if (NewMailNotifierAgentSettings::beepOnNewMails()) {
         KNotification::beep();
     }
 }
 
 void NewMailNotifierAgent::slotInstanceNameChanged(const Akonadi::AgentInstance &instance)
 {
-    if (!isActive())
+    if (!isActive()) {
         return;
+    }
 
     const QString identifier(instance.identifier());
     if (mCacheResourceName.contains(identifier)) {
@@ -518,21 +515,20 @@ void NewMailNotifierAgent::slotInstanceNameChanged(const Akonadi::AgentInstance
 
 void NewMailNotifierAgent::slotInstanceStatusChanged(const Akonadi::AgentInstance &instance)
 {
-    if (!isActive())
+    if (!isActive()) {
         return;
+    }
 
     const QString identifier(instance.identifier());
-    switch(instance.status()) {
+    switch (instance.status()) {
     case Akonadi::AgentInstance::Broken:
-    case Akonadi::AgentInstance::Idle:
-    {
+    case Akonadi::AgentInstance::Idle: {
         if (mInstanceNameInProgress.contains(identifier)) {
             mInstanceNameInProgress.removeAll(identifier);
         }
         break;
     }
-    case Akonadi::AgentInstance::Running:
-    {
+    case Akonadi::AgentInstance::Running: {
         if (!excludeAgentType(instance)) {
             if (!mInstanceNameInProgress.contains(identifier)) {
                 mInstanceNameInProgress.append(identifier);
@@ -548,11 +544,11 @@ void NewMailNotifierAgent::slotInstanceStatusChanged(const Akonadi::AgentInstanc
 
 bool NewMailNotifierAgent::excludeAgentType(const Akonadi::AgentInstance &instance)
 {
-    if ( instance.type().mimeTypes().contains( KMime::Message::mimeType() ) ) {
-        const QStringList capabilities( instance.type().capabilities() );
-        if ( capabilities.contains( QLatin1String("Resource") ) &&
-             !capabilities.contains( QLatin1String("Virtual") ) &&
-             !capabilities.contains( QLatin1String("MailTransport") ) ) {
+    if (instance.type().mimeTypes().contains(KMime::Message::mimeType())) {
+        const QStringList capabilities(instance.type().capabilities());
+        if (capabilities.contains(QStringLiteral("Resource")) &&
+                !capabilities.contains(QStringLiteral("Virtual")) &&
+                !capabilities.contains(QStringLiteral("MailTransport"))) {
             return false;
         } else {
             return true;
@@ -563,8 +559,9 @@ bool NewMailNotifierAgent::excludeAgentType(const Akonadi::AgentInstance &instan
 
 void NewMailNotifierAgent::slotInstanceRemoved(const Akonadi::AgentInstance &instance)
 {
-    if (!isActive())
+    if (!isActive()) {
         return;
+    }
 
     const QString identifier(instance.identifier());
     if (mInstanceNameInProgress.contains(identifier)) {
@@ -579,10 +576,10 @@ void NewMailNotifierAgent::slotInstanceAdded(const Akonadi::AgentInstance &insta
 
 void NewMailNotifierAgent::printDebug()
 {
-    kDebug()<<"instance in progress: "<<mInstanceNameInProgress
-            <<"\n notifier enabled : "<<NewMailNotifierAgentSettings::enabled()
-            <<"\n check in progress : "<<!mInstanceNameInProgress.isEmpty()
-            <<"\n beep on new mails: "<<NewMailNotifierAgentSettings::beepOnNewMails();
+    qCDebug(NEWMAILNOTIFIER_LOG) << "instance in progress: " << mInstanceNameInProgress
+                                 << "\n notifier enabled : " << NewMailNotifierAgentSettings::enabled()
+                                 << "\n check in progress : " << !mInstanceNameInProgress.isEmpty()
+                                 << "\n beep on new mails: " << NewMailNotifierAgentSettings::beepOnNewMails();
 }
 
 bool NewMailNotifierAgent::isActive() const
@@ -590,6 +587,5 @@ bool NewMailNotifierAgent::isActive() const
     return isOnline() && NewMailNotifierAgentSettings::enabled();
 }
 
-AKONADI_AGENT_MAIN( NewMailNotifierAgent )
-
+AKONADI_AGENT_MAIN(NewMailNotifierAgent)
 
