@@ -26,46 +26,57 @@
 
 #include <KLocalizedString>
 #include <KNotifyConfigWidget>
-#include <KLineEdit>
+#include <QLineEdit>
 #include <KCheckableProxyModel>
-#include <KPushButton>
-#include <KMenu>
+#include <QPushButton>
 #include <KHelpMenu>
-#include <KAboutData>
+#include <kaboutdata.h>
+#include <QIcon>
 
 #include <QTabWidget>
 #include <QCheckBox>
 #include <QGroupBox>
 #include <QVBoxLayout>
 #include <QLabel>
-#include <QDebug>
 #include <QWhatsThis>
+#include <QAction>
 
-#include <Akonadi/CollectionView>
-#include <Akonadi/CollectionModel>
-#include <Akonadi/RecursiveCollectionFilterProxyModel>
-#include <Akonadi/CollectionFilterProxyModel>
-#include <Akonadi/CollectionModifyJob>
+#include <AkonadiWidgets/CollectionView>
+#include <AkonadiCore/CollectionModel>
+#include <AkonadiCore/RecursiveCollectionFilterProxyModel>
+#include <AkonadiCore/CollectionFilterProxyModel>
+#include <AkonadiCore/CollectionModifyJob>
+#include <KSharedConfig>
+#include <QDialogButtonBox>
+#include <KConfigGroup>
 
-static const char * textToSpeakMessage =
-        I18N_NOOP( "<qt>"
+static const char *textToSpeakMessage =
+    I18N_NOOP("<qt>"
               "<p>Here you can define message. "
               "You can use:</p>"
               "<ul>"
               "<li>%s set subject</li>"
               "<li>%f set from</li>"
               "</ul>"
-              "</qt>" );
+              "</qt>");
 
 NewMailNotifierSettingsDialog::NewMailNotifierSettingsDialog(QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
 {
-    setCaption( i18n("New Mail Notifier settings") );
-    setWindowIcon( KIcon( QLatin1String("kmail") ) );
-    setButtons( Help | Ok|Cancel );
-    connect(this, SIGNAL(okClicked()), this, SLOT(slotOkClicked()));
+    setWindowTitle(i18n("New Mail Notifier settings"));
+    setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &NewMailNotifierSettingsDialog::slotOkClicked);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &NewMailNotifierSettingsDialog::reject);
 
     QWidget *w = new QWidget;
+    mainLayout->addWidget(w);
+    mainLayout->addWidget(buttonBox);
     QVBoxLayout *lay = new QVBoxLayout;
     w->setLayout(lay);
     QTabWidget *tab = new QTabWidget;
@@ -107,7 +118,7 @@ NewMailNotifierSettingsDialog::NewMailNotifierSettingsDialog(QWidget *parent)
     vbox->addStretch();
     tab->addTab(settings, i18n("Display"));
 
-
+#ifdef HAVE_SPEECH
     QWidget *textSpeakWidget = new QWidget;
     vbox = new QVBoxLayout;
     textSpeakWidget->setLayout(vbox);
@@ -115,18 +126,18 @@ NewMailNotifierSettingsDialog::NewMailNotifierSettingsDialog(QWidget *parent)
     mTextToSpeak->setChecked(NewMailNotifierAgentSettings::textToSpeakEnabled());
     vbox->addWidget(mTextToSpeak);
 
-    QLabel *howIsItWork = new QLabel(i18n( "<a href=\"whatsthis\">How does this work?</a>" ));
+    QLabel *howIsItWork = new QLabel(i18n("<a href=\"whatsthis\">How does this work?</a>"));
     howIsItWork->setTextInteractionFlags(Qt::LinksAccessibleByMouse);
     howIsItWork->setContextMenuPolicy(Qt::NoContextMenu);
     vbox->addWidget(howIsItWork);
-    connect(howIsItWork, SIGNAL(linkActivated(QString)),SLOT(slotHelpLinkClicked(QString)) );
+    connect(howIsItWork, &QLabel::linkActivated, this, &NewMailNotifierSettingsDialog::slotHelpLinkClicked);
 
     QHBoxLayout *textToSpeakLayout = new QHBoxLayout;
     textToSpeakLayout->setMargin(0);
     QLabel *lab = new QLabel(i18n("Message:"));
     textToSpeakLayout->addWidget(lab);
-    mTextToSpeakSetting = new KLineEdit;
-    mTextToSpeakSetting->setClearButtonShown(true);
+    mTextToSpeakSetting = new QLineEdit;
+    mTextToSpeakSetting->setClearButtonEnabled(true);
     mTextToSpeakSetting->setText(NewMailNotifierAgentSettings::textToSpeak());
     mTextToSpeakSetting->setEnabled(mTextToSpeak->isChecked());
     mTextToSpeakSetting->setWhatsThis(i18n(textToSpeakMessage));
@@ -134,74 +145,70 @@ NewMailNotifierSettingsDialog::NewMailNotifierSettingsDialog(QWidget *parent)
     vbox->addLayout(textToSpeakLayout);
     vbox->addStretch();
     tab->addTab(textSpeakWidget, i18n("Text to Speak"));
-    connect(mTextToSpeak, SIGNAL(toggled(bool)), mTextToSpeakSetting, SLOT(setEnabled(bool)));
+    connect(mTextToSpeak, &QCheckBox::toggled, mTextToSpeakSetting, &QLineEdit::setEnabled);
+#else
+    mTextToSpeak = Q_NULLPTR;
+    mTextToSpeakSetting = Q_NULLPTR;
+#endif
 
     mNotify = new KNotifyConfigWidget(this);
-    mNotify->setApplication(QLatin1String("akonadi_newmailnotifier_agent"));
+    mNotify->setApplication(QStringLiteral("akonadi_newmailnotifier_agent"));
     tab->addTab(mNotify, i18n("Notify"));
 
     mSelectCollection = new NewMailNotifierSelectCollectionWidget;
     tab->addTab(mSelectCollection, i18n("Folders"));
 
-    setMainWidget(w);
+    KAboutData aboutData = KAboutData(
+                               QStringLiteral("newmailnotifieragent"),
+                               i18n("New Mail Notifier Agent"),
+                               QLatin1String(KDEPIM_RUNTIME_VERSION),
+                               i18n("Notifies about new mail."),
+                               KAboutLicense::GPL_V2,
+                               i18n("Copyright (C) 2013-2015 Laurent Montel"));
 
-    mAboutData = new KAboutData(
-                QByteArray( "newmailnotifieragent" ),
-                QByteArray(),
-                ki18n( "New Mail Notifier Agent" ),
-                QByteArray( KDEPIM_RUNTIME_VERSION ),
-                ki18n( "Notifies about new mail." ),
-                KAboutData::License_GPL_V2,
-                ki18n( "Copyright (C) 2013 Laurent Montel" ) );
+    aboutData.addAuthor(i18n("Laurent Montel"),
+                        i18n("Maintainer"), QStringLiteral("montel@kde.org"));
+    aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"),
+                            i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
-    mAboutData->addAuthor( ki18n( "Laurent Montel" ),
-                         ki18n( "Maintainer" ), "montel@kde.org" );
-
-    mAboutData->setProgramIconName( QLatin1String("kmail") );
-    mAboutData->setTranslator( ki18nc( "NAME OF TRANSLATORS", "Your names" ),
-                             ki18nc( "EMAIL OF TRANSLATORS", "Your emails" ) );
-
-
-    KHelpMenu *helpMenu = new KHelpMenu(this, mAboutData, true);
+    KHelpMenu *helpMenu = new KHelpMenu(this, aboutData, true);
     //Initialize menu
-    KMenu *menu = helpMenu->menu();
-    helpMenu->action(KHelpMenu::menuAboutApp)->setIcon(KIcon(QLatin1String("kmail")));
-    setButtonMenu( Help, menu );
+    QMenu *menu = helpMenu->menu();
+    helpMenu->action(KHelpMenu::menuAboutApp)->setIcon(QIcon::fromTheme(QStringLiteral("kmail")));
+    buttonBox->button(QDialogButtonBox::Help)->setMenu(menu);
     readConfig();
 }
 
 NewMailNotifierSettingsDialog::~NewMailNotifierSettingsDialog()
 {
     writeConfig();
-    delete mAboutData;
 }
 
 static const char *myConfigGroupName = "NewMailNotifierDialog";
 
 void NewMailNotifierSettingsDialog::readConfig()
 {
-    KConfigGroup group( KGlobal::config(), myConfigGroupName );
+    KConfigGroup group(KSharedConfig::openConfig(), myConfigGroupName);
 
-    const QSize size = group.readEntry( "Size", QSize(500, 300) );
-    if ( size.isValid() ) {
-        resize( size );
+    const QSize size = group.readEntry("Size", QSize(500, 300));
+    if (size.isValid()) {
+        resize(size);
     }
 }
 
 void NewMailNotifierSettingsDialog::writeConfig()
 {
-    KConfigGroup group( KGlobal::config(), myConfigGroupName );
-    group.writeEntry( "Size", size() );
+    KConfigGroup group(KSharedConfig::openConfig(), myConfigGroupName);
+    group.writeEntry("Size", size());
     group.sync();
 }
 
-
 void NewMailNotifierSettingsDialog::slotHelpLinkClicked(const QString &)
 {
     const QString help =
-            i18n( textToSpeakMessage);
+        i18n(textToSpeakMessage);
 
-    QWhatsThis::showText( QCursor::pos(), help );
+    QWhatsThis::showText(QCursor::pos(), help);
 }
 
 void NewMailNotifierSettingsDialog::slotOkClicked()
@@ -213,13 +220,13 @@ void NewMailNotifierSettingsDialog::slotOkClicked()
     NewMailNotifierAgentSettings::setShowSubject(mShowSubject->isChecked());
     NewMailNotifierAgentSettings::setShowFolder(mShowFolders->isChecked());
     NewMailNotifierAgentSettings::setExcludeEmailsFromMe(mExcludeMySelf->isChecked());
+#ifdef HAVE_SPEECH
     NewMailNotifierAgentSettings::setTextToSpeakEnabled(mTextToSpeak->isChecked());
     NewMailNotifierAgentSettings::setTextToSpeak(mTextToSpeakSetting->text());
+#endif
     NewMailNotifierAgentSettings::setShowButtonToDisplayMail(mAllowToShowMail->isChecked());
-    NewMailNotifierAgentSettings::self()->writeConfig();
+    NewMailNotifierAgentSettings::self()->save();
     mNotify->save();
     accept();
 }
 
-
-
