@@ -20,7 +20,7 @@
 #ifndef GIDMIGRATOR_H
 #define GIDMIGRATOR_H
 
-#include <migration/migratorbase.h>
+#include <migratorbase.h>
 #include <KJob>
 
 class GidMigrator: public MigratorBase
@@ -39,7 +39,7 @@ public:
 
 protected:
     virtual void startWork();
-private slots:
+private Q_SLOTS:
     void migrationFinished(KJob *);
 private:
     QString mMimeType;
