@@ -26,7 +26,8 @@
 
 class DavProtocolBase;
 
-namespace KIO {
+namespace KIO
+{
 class DavJob;
 }
 
@@ -43,7 +44,7 @@ class QDomDocument;
  */
 class DavManager
 {
-  public:
+public:
     /**
      * Destroys the DAV manager.
      */
@@ -52,7 +53,7 @@ class DavManager
     /**
      * Returns the global instance of the DAV manager.
      */
-    static DavManager* self();
+    static DavManager *self();
 
     /**
      * Returns a preconfigured DAV PROPFIND job.
@@ -61,7 +62,7 @@ class DavManager
      * @param document The query XML document.
      * @param depth The Depth: value to send in the HTTP request
      */
-    KIO::DavJob* createPropFindJob( const KUrl &url, const QDomDocument &document, const QString &depth = QLatin1String( "1" ) ) const;
+    KIO::DavJob *createPropFindJob(const KUrl &url, const QDomDocument &document, const QString &depth = QLatin1String("1")) const;
 
     /**
      * Returns a preconfigured DAV REPORT job.
@@ -70,7 +71,7 @@ class DavManager
      * @param document The query XML document.
      * @param depth The Depth: value to send in the HTTP request
      */
-    KIO::DavJob* createReportJob( const KUrl &url, const QDomDocument &document, const QString &depth = QLatin1String( "1" ) ) const;
+    KIO::DavJob *createReportJob(const KUrl &url, const QDomDocument &document, const QString &depth = QLatin1String("1")) const;
 
     /**
      * Returns a preconfigured DAV PROPPATCH job.
@@ -78,14 +79,14 @@ class DavManager
      * @param url The target url of the job.
      * @param document The query XML document.
      */
-    KIO::DavJob* createPropPatchJob( const KUrl &url, const QDomDocument &document ) const;
+    KIO::DavJob *createPropPatchJob(const KUrl &url, const QDomDocument &document) const;
 
     /**
      * Returns the DAV protocol dialect object for the given DAV @p protocol.
      */
-    const DavProtocolBase* davProtocol( DavUtils::Protocol protocol );
+    const DavProtocolBase *davProtocol(DavUtils::Protocol protocol);
 
-  private:
+private:
     /**
      * Creates a new DAV manager.
      */
@@ -94,11 +95,11 @@ class DavManager
     /**
      * Creates a new protocol.
      */
-    bool createProtocol( DavUtils::Protocol protocol );
+    bool createProtocol(DavUtils::Protocol protocol);
 
-    typedef QMap<DavUtils::Protocol, DavProtocolBase*> protocolsMap;
+    typedef QMap<DavUtils::Protocol, DavProtocolBase *> protocolsMap;
     protocolsMap mProtocols;
-    static DavManager* mSelf;
+    static DavManager *mSelf;
 };
 
 #endif
