@@ -24,7 +24,6 @@
 #include <QtCore/QList>
 #include <QtXml/QDomDocument>
 
-
 /**
  * @short Base class for various DAV groupware dialects.
  *
@@ -38,7 +37,7 @@
  */
 class DavProtocolBase
 {
-  public:
+public:
     /**
      * Destroys the dav protocol base.
      */
@@ -98,19 +97,19 @@ class DavProtocolBase
      * Returns a list of XML documents that represent DAV queries to
      * list all available DAV resources inside a specific DAV collection.
      */
-    virtual QList<QDomDocument> itemsQueries() const = 0;
+    virtual QVector<QDomDocument> itemsQueries() const = 0;
 
     /**
      * Returns the mime type of items fetched by query at index @p index
      * in the list return by @ref itemsQueries().
      */
-    virtual QString mimeTypeForQuery( int index ) const = 0;
+    virtual QString mimeTypeForQuery(int index) const = 0;
 
     /**
      * Returns the possible content types for the collection that
      * is described by the passed @p propstat element of a PROPFIND result.
      */
-    virtual DavCollection::ContentTypes collectionContentTypes( const QDomElement &propstat ) const = 0;
+    virtual DavCollection::ContentTypes collectionContentTypes(const QDomElement &propstat) const = 0;
 
     /**
      * Returns the mimetype that shall be used for contact DAV resources.
