@@ -23,26 +23,26 @@
 
 #include "davutils.h"
 
-#include <kdialog.h>
+#include <QDialog>
 
 #include <QtCore/QList>
 #include <QtCore/QPair>
 #include <QtCore/QString>
-
+class QPushButton;
 class KConfigDialogManager;
 class QStandardItemModel;
 
-class ConfigDialog : public KDialog
+class ConfigDialog : public QDialog
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
-    explicit ConfigDialog( QWidget *parent = 0 );
+public:
+    explicit ConfigDialog(QWidget *parent = Q_NULLPTR);
     virtual ~ConfigDialog();
 
-    void setPassword( const QString &password );
+    void setPassword(const QString &password);
 
-  private Q_SLOTS:
+private Q_SLOTS:
     void checkUserInput();
     void onAddButtonClicked();
     void onSearchButtonClicked();
@@ -52,15 +52,18 @@ class ConfigDialog : public KDialog
     void onOkClicked();
     void onCancelClicked();
 
-  private:
-    void addModelRow( const QString &protocol, const QString &url );
-    void insertModelRow( int index, const QString &protocol, const QString &url );
+private:
+    void readConfig();
+    void writeConfig();
+    void addModelRow(const QString &protocol, const QString &url);
+    void insertModelRow(int index, const QString &protocol, const QString &url);
 
     Ui::ConfigDialog mUi;
     KConfigDialogManager *mManager;
     QList< QPair<QString, DavUtils::Protocol> > mAddedUrls;
     QList< QPair<QString, DavUtils::Protocol> > mRemovedUrls;
     QStandardItemModel *mModel;
+    QPushButton *mOkButton;
 };
 
 #endif
