@@ -19,24 +19,24 @@
 #ifndef DAVPROTOCOLATTRIBUTE_H
 #define DAVPROTOCOLATTRIBUTE_H
 
-#include <akonadi/attribute.h>
+#include <attribute.h>
 
 #include <QtCore/QString>
 
 class DavProtocolAttribute : public Akonadi::Attribute
 {
-  public:
-    explicit DavProtocolAttribute( int protocol = 0 );
+public:
+    explicit DavProtocolAttribute(int protocol = 0);
 
-    void setDavProtocol( int protocol );
+    void setDavProtocol(int protocol);
     int davProtocol() const;
 
-    virtual Akonadi::Attribute* clone() const;
-    virtual QByteArray type() const;
-    virtual QByteArray serialized() const;
-    virtual void deserialize( const QByteArray &data );
+    Akonadi::Attribute *clone() const Q_DECL_OVERRIDE;
+    QByteArray type() const Q_DECL_OVERRIDE;
+    QByteArray serialized() const Q_DECL_OVERRIDE;
+    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
 
-  private:
+private:
     int mDavProtocol;
 };
 
