@@ -26,26 +26,29 @@
 
 class ChangeCollectionTask : public ResourceTask
 {
-  Q_OBJECT
+    Q_OBJECT
 
 public:
-  explicit ChangeCollectionTask( ResourceStateInterface::Ptr resource, QObject *parent = 0 );
-  virtual ~ChangeCollectionTask();
+    explicit ChangeCollectionTask(ResourceStateInterface::Ptr resource, QObject *parent = Q_NULLPTR);
+    virtual ~ChangeCollectionTask();
 
-private slots:
-  void onRenameDone( KJob *job );
-  void onSubscribeDone( KJob *job );
-  void onSetAclDone( KJob *job );
-  void onSetMetaDataDone( KJob *job );
+    void syncEnabledState(bool);
+
+private Q_SLOTS:
+    void onRenameDone(KJob *job);
+    void onSubscribeDone(KJob *job);
+    void onSetAclDone(KJob *job);
+    void onSetMetaDataDone(KJob *job);
 
 protected:
-  virtual void doStart( KIMAP::Session *session );
+    void doStart(KIMAP::Session *session) Q_DECL_OVERRIDE;
 
 private:
-  void endTaskIfNeeded();
+    void endTaskIfNeeded();
 
-  int m_pendingJobs;
-  Akonadi::Collection m_collection;
+    int m_pendingJobs;
+    Akonadi::Collection m_collection;
+    bool m_syncEnabledState;
 };
 
 #endif
