@@ -20,23 +20,24 @@
 #ifndef MESSAGEHELPER_H
 #define MESSAGEHELPER_H
 
-#include <Akonadi/Item>
+#include <AkonadiCore/Item>
 #include <KMime/Message>
-#include <KIMAP/FetchJob>
+#include <kimap/FetchJob>
 #include <boost/shared_ptr.hpp>
 
-class MessageHelper {
+class MessageHelper
+{
 public:
     typedef boost::shared_ptr<MessageHelper> Ptr;
 
     virtual ~MessageHelper();
     virtual Akonadi::Item createItemFromMessage(KMime::Message::Ptr message,
-                                                const qint64 uid,
-                                                const qint64 size,
-                                                const QList<KIMAP::MessageAttribute> &attrs,
-                                                const QList<QByteArray> &flags,
-                                                const KIMAP::FetchJob::FetchScope &scope,
-                                                bool &ok) const;
+            const qint64 uid,
+            const qint64 size,
+            const QList<KIMAP::MessageAttribute> &attrs,
+            const QList<QByteArray> &flags,
+            const KIMAP::FetchJob::FetchScope &scope,
+            bool &ok) const;
 };
 
 #endif
