@@ -23,21 +23,31 @@
 #include "ui_serverinfo.h"
 
 #include <KLocalizedString>
+#include <QDialogButtonBox>
+#include <KConfigGroup>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 ServerInfoDialog::ServerInfoDialog(ImapResourceBase *parentResource, QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
 {
-    setCaption(
-      i18nc( "@title:window Dialog title for dialog showing information about a server",
-             "Server Info" ) );
-    setButtons( KDialog::Close );
-    setAttribute( Qt::WA_DeleteOnClose );
+    setWindowTitle(
+        i18nc("@title:window Dialog title for dialog showing information about a server",
+              "Server Info"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    QWidget *w = new QWidget;
+    mainLayout->addWidget(w);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &ServerInfoDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &ServerInfoDialog::reject);
+    setAttribute(Qt::WA_DeleteOnClose);
 
     mServerInfoWidget = new Ui::ServerInfo();
-    mServerInfoWidget->setupUi( this );
-    setMainWidget( mServerInfoWidget->serverInfo );
+    mServerInfoWidget->setupUi(w);
+    mainLayout->addWidget(buttonBox);
     mServerInfoWidget->serverInfo->setPlainText(
-      parentResource->serverCapabilities().join( QLatin1String( "\n" ) ) );
+        parentResource->serverCapabilities().join(QLatin1String("\n")));
 }
 
 ServerInfoDialog::~ServerInfoDialog()
