@@ -24,26 +24,22 @@
 #include <imapresource.h>
 
 #include <collectionannotationsattribute.h>
+#include <AkonadiCore/EntityDisplayAttribute>
+#include <AkonadiCore/CachePolicy>
 #include <noselectattribute.h>
-#include <Akonadi/EntityDisplayAttribute>
-#include <Akonadi/CachePolicy>
 #include <Akonadi/KMime/MessageParts>
+#include "kolabresource_debug.h"
 
-
-KolabResourceState::KolabResourceState(ImapResource* resource, const TaskArguments& arguments)
+KolabResourceState::KolabResourceState(ImapResource *resource, const TaskArguments &arguments)
     : ResourceState(resource, arguments)
 {
 
 }
 
-void KolabResourceState::collectionAttributesRetrieved(const Akonadi::Collection& collection)
+static Akonadi::Collection processAnnotations(const Akonadi::Collection &collection)
 {
-    if (!collection.isValid() && collection.remoteId().isEmpty()) {
-        ResourceState::collectionAttributesRetrieved(collection);
-        return;
-    }
-    Akonadi::Collection col = collection;
-    if (col.attribute<Akonadi::CollectionAnnotationsAttribute>()) {
+    if (collection.attribute<Akonadi::CollectionAnnotationsAttribute>()) {
+        Akonadi::Collection col = collection;
         const QMap<QByteArray, QByteArray> rawAnnotations = col.attribute<Akonadi::CollectionAnnotationsAttribute>()->annotations();
         const QByteArray type = KolabHelpers::getFolderTypeAnnotation(rawAnnotations);
         const Kolab::FolderType folderType = KolabHelpers::folderTypeFromString(type);
@@ -51,7 +47,7 @@ void KolabResourceState::collectionAttributesRetrieved(const Akonadi::Collection
 
         const QString icon = KolabHelpers::getIcon(folderType);
         if (!icon.isEmpty()) {
-            kDebug() << " setting icon " << icon;
+            // qCDebug(KOLABRESOURCE_LOG) << " setting icon " << icon;
             Akonadi::EntityDisplayAttribute *attr = col.attribute<Akonadi::EntityDisplayAttribute>(Akonadi::Collection::AddIfMissing);
             attr->setIconName(icon);
         }
@@ -68,14 +64,39 @@ void KolabResourceState::collectionAttributesRetrieved(const Akonadi::Collection
                 col.setCachePolicy(cachePolicy);
             }
         }
+        if (folderType == Kolab::ConfigurationType) {
+            //we want to hide this folder from indexing and display, but still have the data available locally.
+            col.setEnabled(false);
+            col.setShouldList(Akonadi::Collection::ListSync, true);
+        }
         if (!KolabHelpers::isHandledType(folderType)) {
             //If we don't handle the folder, make sure we don't download the messages
             col.attribute<NoSelectAttribute>(Akonadi::Entity::AddIfMissing);
         }
+        return col;
     }
+    return collection;
+}
+
+void KolabResourceState::collectionAttributesRetrieved(const Akonadi::Collection &collection)
+{
+    if (!collection.isValid() && collection.remoteId().isEmpty()) {
+        ResourceState::collectionAttributesRetrieved(collection);
+        return;
+    }
+    const Akonadi::Collection col = processAnnotations(collection);
     ResourceState::collectionAttributesRetrieved(col);
 }
 
+void KolabResourceState::collectionsRetrieved(const Akonadi::Collection::List &collections)
+{
+    Akonadi::Collection::List modifiedCollections;
+    Q_FOREACH (const Akonadi::Collection &col, collections) {
+        modifiedCollections << processAnnotations(col);
+    }
+    ResourceState::collectionsRetrieved(modifiedCollections);
+}
+
 MessageHelper::Ptr KolabResourceState::messageHelper() const
 {
     return MessageHelper::Ptr(new KolabMessageHelper(collection()));
