@@ -53,7 +53,7 @@ public:
         , mSettings(new Settings(componentData().config()))
     {
         // The resource needs network when the path refers to a non local file.
-        setNeedsNetwork(!QUrl::fromLocalFile(mSettings->path()).isLocalFile());
+        setNeedsNetwork(!QUrl(mSettings->path()).isLocalFile());
     }
     ~SingleFileResource()
     {
@@ -80,7 +80,7 @@ public:
             return;
         }
 
-        mCurrentUrl = QUrl::fromLocalFile(mSettings->path());
+        mCurrentUrl = QUrl(mSettings->path()); // path already has scheme
         if (mCurrentHash.isEmpty())
         {
             // First call to readFile() lets see if there is a hash stored in a
